# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!injective/oracle/v1beta1/tx.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x95\x01\n\x16MsgRelayProviderPrices\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x0f\n\x07symbols\x18\x03 \x03(\t\x12>\n\x06prices\x18\x04 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgRelayProviderPricesResponse\"\x8e\x01\n\x16MsgRelayPriceFeedPrice\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x02 \x03(\t\x12\r\n\x05quote\x18\x03 \x03(\t\x12=\n\x05price\x18\x04 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgRelayPriceFeedPriceResponse\"o\n\x11MsgRelayBandRates\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0f\n\x07symbols\x18\x02 \x03(\t\x12\r\n\x05rates\x18\x03 \x03(\x04\x12\x15\n\rresolve_times\x18\x04 \x03(\x04\x12\x12\n\nrequestIDs\x18\x05 \x03(\x04\"\x1b\n\x19MsgRelayBandRatesResponse\"Z\n\x18MsgRelayCoinbaseMessages\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08messages\x18\x02 \x03(\x0c\x12\x12\n\nsignatures\x18\x03 \x03(\x0c:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\"\n MsgRelayCoinbaseMessagesResponse\"F\n\x16MsgRequestBandIBCRates\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgRequestBandIBCRatesResponse\"v\n\x12MsgRelayPythPrices\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x46\n\x12price_attestations\x18\x02 \x03(\x0b\x32*.injective.oracle.v1beta1.PriceAttestation:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1c\n\x1aMsgRelayPythPricesResponse2\x86\x06\n\x03Msg\x12\x81\x01\n\x13RelayProviderPrices\x12\x30.injective.oracle.v1beta1.MsgRelayProviderPrices\x1a\x38.injective.oracle.v1beta1.MsgRelayProviderPricesResponse\x12\x81\x01\n\x13RelayPriceFeedPrice\x12\x30.injective.oracle.v1beta1.MsgRelayPriceFeedPrice\x1a\x38.injective.oracle.v1beta1.MsgRelayPriceFeedPriceResponse\x12r\n\x0eRelayBandRates\x12+.injective.oracle.v1beta1.MsgRelayBandRates\x1a\x33.injective.oracle.v1beta1.MsgRelayBandRatesResponse\x12\x81\x01\n\x13RequestBandIBCRates\x12\x30.injective.oracle.v1beta1.MsgRequestBandIBCRates\x1a\x38.injective.oracle.v1beta1.MsgRequestBandIBCRatesResponse\x12\x87\x01\n\x15RelayCoinbaseMessages\x12\x32.injective.oracle.v1beta1.MsgRelayCoinbaseMessages\x1a:.injective.oracle.v1beta1.MsgRelayCoinbaseMessagesResponse\x12u\n\x0fRelayPythPrices\x12,.injective.oracle.v1beta1.MsgRelayPythPrices\x1a\x34.injective.oracle.v1beta1.MsgRelayPythPricesResponseBNZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types'
  _MSGRELAYPROVIDERPRICES.fields_by_name['prices']._options = None
  _MSGRELAYPROVIDERPRICES.fields_by_name['prices']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGRELAYPROVIDERPRICES._options = None
  _MSGRELAYPROVIDERPRICES._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGRELAYPRICEFEEDPRICE.fields_by_name['price']._options = None
  _MSGRELAYPRICEFEEDPRICE.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGRELAYPRICEFEEDPRICE._options = None
  _MSGRELAYPRICEFEEDPRICE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGRELAYCOINBASEMESSAGES._options = None
  _MSGRELAYCOINBASEMESSAGES._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGREQUESTBANDIBCRATES._options = None
  _MSGREQUESTBANDIBCRATES._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGRELAYPYTHPRICES._options = None
  _MSGRELAYPYTHPRICES._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGRELAYPROVIDERPRICES._serialized_start=125
  _MSGRELAYPROVIDERPRICES._serialized_end=274
  _MSGRELAYPROVIDERPRICESRESPONSE._serialized_start=276
  _MSGRELAYPROVIDERPRICESRESPONSE._serialized_end=308
  _MSGRELAYPRICEFEEDPRICE._serialized_start=311
  _MSGRELAYPRICEFEEDPRICE._serialized_end=453
  _MSGRELAYPRICEFEEDPRICERESPONSE._serialized_start=455
  _MSGRELAYPRICEFEEDPRICERESPONSE._serialized_end=487
  _MSGRELAYBANDRATES._serialized_start=489
  _MSGRELAYBANDRATES._serialized_end=600
  _MSGRELAYBANDRATESRESPONSE._serialized_start=602
  _MSGRELAYBANDRATESRESPONSE._serialized_end=629
  _MSGRELAYCOINBASEMESSAGES._serialized_start=631
  _MSGRELAYCOINBASEMESSAGES._serialized_end=721
  _MSGRELAYCOINBASEMESSAGESRESPONSE._serialized_start=723
  _MSGRELAYCOINBASEMESSAGESRESPONSE._serialized_end=757
  _MSGREQUESTBANDIBCRATES._serialized_start=759
  _MSGREQUESTBANDIBCRATES._serialized_end=829
  _MSGREQUESTBANDIBCRATESRESPONSE._serialized_start=831
  _MSGREQUESTBANDIBCRATESRESPONSE._serialized_end=863
  _MSGRELAYPYTHPRICES._serialized_start=865
  _MSGRELAYPYTHPRICES._serialized_end=983
  _MSGRELAYPYTHPRICESRESPONSE._serialized_start=985
  _MSGRELAYPYTHPRICESRESPONSE._serialized_end=1013
  _MSG._serialized_start=1016
  _MSG._serialized_end=1790
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from injective.ocr.v1beta1 import tx_pb2 as injective_dot_ocr_dot_v1beta1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the OCR Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateFeed = channel.unary_unary(
                '/injective.ocr.v1beta1.Msg/CreateFeed',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgCreateFeed.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgCreateFeedResponse.FromString,
                )
        self.UpdateFeed = channel.unary_unary(
                '/injective.ocr.v1beta1.Msg/UpdateFeed',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgUpdateFeed.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgUpdateFeedResponse.FromString,
                )
        self.Transmit = channel.unary_unary(
                '/injective.ocr.v1beta1.Msg/Transmit',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransmit.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransmitResponse.FromString,
                )
        self.FundFeedRewardPool = channel.unary_unary(
                '/injective.ocr.v1beta1.Msg/FundFeedRewardPool',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgFundFeedRewardPool.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgFundFeedRewardPoolResponse.FromString,
                )
        self.WithdrawFeedRewardPool = channel.unary_unary(
                '/injective.ocr.v1beta1.Msg/WithdrawFeedRewardPool',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgWithdrawFeedRewardPool.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgWithdrawFeedRewardPoolResponse.FromString,
                )
        self.SetPayees = channel.unary_unary(
                '/injective.ocr.v1beta1.Msg/SetPayees',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgSetPayees.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgSetPayeesResponse.FromString,
                )
        self.TransferPayeeship = channel.unary_unary(
                '/injective.ocr.v1beta1.Msg/TransferPayeeship',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransferPayeeship.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransferPayeeshipResponse.FromString,
                )
        self.AcceptPayeeship = channel.unary_unary(
                '/injective.ocr.v1beta1.Msg/AcceptPayeeship',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgAcceptPayeeship.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgAcceptPayeeshipResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the OCR Msg service.
    """

    def CreateFeed(self, request, context):
        """CreateFeed defines a method for creating feed by module admin
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeed(self, request, context):
        """CreateFeed defines a method for creating feed by feed admin or feed billing admin
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Transmit(self, request, context):
        """Transmit defines a method for transmitting the feed info by transmitter
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FundFeedRewardPool(self, request, context):
        """FundFeedRewardPool defines a method to put funds into feed reward pool
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawFeedRewardPool(self, request, context):
        """WithdrawFeedRewardPool defines a method to witdhraw feed reward by feed admin or billing admin
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPayees(self, request, context):
        """SetPayees defines a method to set payees for transmitters (batch action)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TransferPayeeship(self, request, context):
        """TransferPayeeship defines a method for a payee to transfer reward receive ownership
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcceptPayeeship(self, request, context):
        """AcceptPayeeship defines a method for a new payee to accept reward receive ownership
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateFeed': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeed,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgCreateFeed.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgCreateFeedResponse.SerializeToString,
            ),
            'UpdateFeed': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeed,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgUpdateFeed.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgUpdateFeedResponse.SerializeToString,
            ),
            'Transmit': grpc.unary_unary_rpc_method_handler(
                    servicer.Transmit,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransmit.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransmitResponse.SerializeToString,
            ),
            'FundFeedRewardPool': grpc.unary_unary_rpc_method_handler(
                    servicer.FundFeedRewardPool,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgFundFeedRewardPool.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgFundFeedRewardPoolResponse.SerializeToString,
            ),
            'WithdrawFeedRewardPool': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawFeedRewardPool,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgWithdrawFeedRewardPool.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgWithdrawFeedRewardPoolResponse.SerializeToString,
            ),
            'SetPayees': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPayees,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgSetPayees.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgSetPayeesResponse.SerializeToString,
            ),
            'TransferPayeeship': grpc.unary_unary_rpc_method_handler(
                    servicer.TransferPayeeship,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransferPayeeship.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransferPayeeshipResponse.SerializeToString,
            ),
            'AcceptPayeeship': grpc.unary_unary_rpc_method_handler(
                    servicer.AcceptPayeeship,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgAcceptPayeeship.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgAcceptPayeeshipResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.ocr.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the OCR Msg service.
    """

    @staticmethod
    def CreateFeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.ocr.v1beta1.Msg/CreateFeed',
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgCreateFeed.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgCreateFeedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.ocr.v1beta1.Msg/UpdateFeed',
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgUpdateFeed.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgUpdateFeedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Transmit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.ocr.v1beta1.Msg/Transmit',
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransmit.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransmitResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FundFeedRewardPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.ocr.v1beta1.Msg/FundFeedRewardPool',
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgFundFeedRewardPool.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgFundFeedRewardPoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WithdrawFeedRewardPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.ocr.v1beta1.Msg/WithdrawFeedRewardPool',
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgWithdrawFeedRewardPool.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgWithdrawFeedRewardPoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetPayees(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.ocr.v1beta1.Msg/SetPayees',
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgSetPayees.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgSetPayeesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TransferPayeeship(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.ocr.v1beta1.Msg/TransferPayeeship',
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransferPayeeship.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgTransferPayeeshipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AcceptPayeeship(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.ocr.v1beta1.Msg/AcceptPayeeship',
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgAcceptPayeeship.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_tx__pb2.MsgAcceptPayeeshipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crisis/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/crisis/v1beta1/tx.proto\x12\x15\x63osmos.crisis.v1beta1\x1a\x14gogoproto/gogo.proto\"\xa4\x01\n\x12MsgVerifyInvariant\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12?\n\x15invariant_module_name\x18\x02 \x01(\tB \xf2\xde\x1f\x1cyaml:\"invariant_module_name\"\x12\x33\n\x0finvariant_route\x18\x03 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"invariant_route\":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1c\n\x1aMsgVerifyInvariantResponse2v\n\x03Msg\x12o\n\x0fVerifyInvariant\x12).cosmos.crisis.v1beta1.MsgVerifyInvariant\x1a\x31.cosmos.crisis.v1beta1.MsgVerifyInvariantResponseB-Z+github.com/cosmos/cosmos-sdk/x/crisis/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crisis.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/crisis/types'
  _MSGVERIFYINVARIANT.fields_by_name['invariant_module_name']._options = None
  _MSGVERIFYINVARIANT.fields_by_name['invariant_module_name']._serialized_options = b'\362\336\037\034yaml:\"invariant_module_name\"'
  _MSGVERIFYINVARIANT.fields_by_name['invariant_route']._options = None
  _MSGVERIFYINVARIANT.fields_by_name['invariant_route']._serialized_options = b'\362\336\037\026yaml:\"invariant_route\"'
  _MSGVERIFYINVARIANT._options = None
  _MSGVERIFYINVARIANT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGVERIFYINVARIANT._serialized_start=80
  _MSGVERIFYINVARIANT._serialized_end=244
  _MSGVERIFYINVARIANTRESPONSE._serialized_start=246
  _MSGVERIFYINVARIANTRESPONSE._serialized_end=274
  _MSG._serialized_start=276
  _MSG._serialized_end=394
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/authz.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/bank/v1beta1/authz.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x88\x01\n\x11SendAuthorization\x12`\n\x0bspend_limit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x11\xd2\xb4-\rAuthorizationB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.authz_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _SENDAUTHORIZATION.fields_by_name['spend_limit']._options = None
  _SENDAUTHORIZATION.fields_by_name['spend_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _SENDAUTHORIZATION._options = None
  _SENDAUTHORIZATION._serialized_options = b'\322\264-\rAuthorization'
  _SENDAUTHORIZATION._serialized_start=138
  _SENDAUTHORIZATION._serialized_end=274
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ibc/applications/transfer/v1/tx.proto\x12\x1cibc.applications.transfer.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1fibc/core/client/v1/client.proto\"\xe3\x02\n\x0bMsgTransfer\x12+\n\x0bsource_port\x18\x01 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"source_port\"\x12\x31\n\x0esource_channel\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_channel\"\x12.\n\x05token\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06sender\x18\x04 \x01(\t\x12\x10\n\x08receiver\x18\x05 \x01(\t\x12Q\n\x0etimeout_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1d\xf2\xde\x1f\x15yaml:\"timeout_height\"\xc8\xde\x1f\x00\x12\x37\n\x11timeout_timestamp\x18\x07 \x01(\x04\x42\x1c\xf2\xde\x1f\x18yaml:\"timeout_timestamp\"\x12\x0c\n\x04memo\x18\x08 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\'\n\x13MsgTransferResponse\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x32o\n\x03Msg\x12h\n\x08Transfer\x12).ibc.applications.transfer.v1.MsgTransfer\x1a\x31.ibc.applications.transfer.v1.MsgTransferResponseB9Z7github.com/cosmos/ibc-go/v2/modules/apps/transfer/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v2/modules/apps/transfer/types'
  _MSGTRANSFER.fields_by_name['source_port']._options = None
  _MSGTRANSFER.fields_by_name['source_port']._serialized_options = b'\362\336\037\022yaml:\"source_port\"'
  _MSGTRANSFER.fields_by_name['source_channel']._options = None
  _MSGTRANSFER.fields_by_name['source_channel']._serialized_options = b'\362\336\037\025yaml:\"source_channel\"'
  _MSGTRANSFER.fields_by_name['token']._options = None
  _MSGTRANSFER.fields_by_name['token']._serialized_options = b'\310\336\037\000'
  _MSGTRANSFER.fields_by_name['timeout_height']._options = None
  _MSGTRANSFER.fields_by_name['timeout_height']._serialized_options = b'\362\336\037\025yaml:\"timeout_height\"\310\336\037\000'
  _MSGTRANSFER.fields_by_name['timeout_timestamp']._options = None
  _MSGTRANSFER.fields_by_name['timeout_timestamp']._serialized_options = b'\362\336\037\030yaml:\"timeout_timestamp\"'
  _MSGTRANSFER._options = None
  _MSGTRANSFER._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGTRANSFER._serialized_start=159
  _MSGTRANSFER._serialized_end=514
  _MSGTRANSFERRESPONSE._serialized_start=516
  _MSGTRANSFERRESPONSE._serialized_end=555
  _MSG._serialized_start=557
  _MSG._serialized_end=668
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from injective.peggy.v1 import query_pb2 as injective_dot_peggy_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/injective.peggy.v1.Query/Params',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.CurrentValset = channel.unary_unary(
                '/injective.peggy.v1.Query/CurrentValset',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryCurrentValsetRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryCurrentValsetResponse.FromString,
                )
        self.ValsetRequest = channel.unary_unary(
                '/injective.peggy.v1.Query/ValsetRequest',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetRequestRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetRequestResponse.FromString,
                )
        self.ValsetConfirm = channel.unary_unary(
                '/injective.peggy.v1.Query/ValsetConfirm',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmResponse.FromString,
                )
        self.ValsetConfirmsByNonce = channel.unary_unary(
                '/injective.peggy.v1.Query/ValsetConfirmsByNonce',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmsByNonceRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmsByNonceResponse.FromString,
                )
        self.LastValsetRequests = channel.unary_unary(
                '/injective.peggy.v1.Query/LastValsetRequests',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastValsetRequestsRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastValsetRequestsResponse.FromString,
                )
        self.LastPendingValsetRequestByAddr = channel.unary_unary(
                '/injective.peggy.v1.Query/LastPendingValsetRequestByAddr',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingValsetRequestByAddrRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingValsetRequestByAddrResponse.FromString,
                )
        self.LastEventByAddr = channel.unary_unary(
                '/injective.peggy.v1.Query/LastEventByAddr',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastEventByAddrRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastEventByAddrResponse.FromString,
                )
        self.GetPendingSendToEth = channel.unary_unary(
                '/injective.peggy.v1.Query/GetPendingSendToEth',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryPendingSendToEth.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryPendingSendToEthResponse.FromString,
                )
        self.BatchFees = channel.unary_unary(
                '/injective.peggy.v1.Query/BatchFees',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchFeeRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchFeeResponse.FromString,
                )
        self.OutgoingTxBatches = channel.unary_unary(
                '/injective.peggy.v1.Query/OutgoingTxBatches',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesResponse.FromString,
                )
        self.LastPendingBatchRequestByAddr = channel.unary_unary(
                '/injective.peggy.v1.Query/LastPendingBatchRequestByAddr',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrResponse.FromString,
                )
        self.BatchRequestByNonce = channel.unary_unary(
                '/injective.peggy.v1.Query/BatchRequestByNonce',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchRequestByNonceRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchRequestByNonceResponse.FromString,
                )
        self.BatchConfirms = channel.unary_unary(
                '/injective.peggy.v1.Query/BatchConfirms',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchConfirmsRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchConfirmsResponse.FromString,
                )
        self.ERC20ToDenom = channel.unary_unary(
                '/injective.peggy.v1.Query/ERC20ToDenom',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryERC20ToDenomRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryERC20ToDenomResponse.FromString,
                )
        self.DenomToERC20 = channel.unary_unary(
                '/injective.peggy.v1.Query/DenomToERC20',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDenomToERC20Request.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDenomToERC20Response.FromString,
                )
        self.GetDelegateKeyByValidator = channel.unary_unary(
                '/injective.peggy.v1.Query/GetDelegateKeyByValidator',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByValidatorAddress.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByValidatorAddressResponse.FromString,
                )
        self.GetDelegateKeyByEth = channel.unary_unary(
                '/injective.peggy.v1.Query/GetDelegateKeyByEth',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByEthAddress.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByEthAddressResponse.FromString,
                )
        self.GetDelegateKeyByOrchestrator = channel.unary_unary(
                '/injective.peggy.v1.Query/GetDelegateKeyByOrchestrator',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByOrchestratorAddress.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByOrchestratorAddressResponse.FromString,
                )
        self.PeggyModuleState = channel.unary_unary(
                '/injective.peggy.v1.Query/PeggyModuleState',
                request_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
                response_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryModuleStateResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service
    """

    def Params(self, request, context):
        """Deployments queries deployments
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CurrentValset(self, request, context):
        """valset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValsetRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValsetConfirm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValsetConfirmsByNonce(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LastValsetRequests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LastPendingValsetRequestByAddr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LastEventByAddr(self, request, context):
        """claim
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPendingSendToEth(self, request, context):
        """batch
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchFees(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OutgoingTxBatches(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LastPendingBatchRequestByAddr(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchRequestByNonce(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchConfirms(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ERC20ToDenom(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomToERC20(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegateKeyByValidator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegateKeyByEth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegateKeyByOrchestrator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PeggyModuleState(self, request, context):
        """Retrieves the entire peggy module's state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'CurrentValset': grpc.unary_unary_rpc_method_handler(
                    servicer.CurrentValset,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryCurrentValsetRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryCurrentValsetResponse.SerializeToString,
            ),
            'ValsetRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.ValsetRequest,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetRequestRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetRequestResponse.SerializeToString,
            ),
            'ValsetConfirm': grpc.unary_unary_rpc_method_handler(
                    servicer.ValsetConfirm,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmResponse.SerializeToString,
            ),
            'ValsetConfirmsByNonce': grpc.unary_unary_rpc_method_handler(
                    servicer.ValsetConfirmsByNonce,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmsByNonceRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmsByNonceResponse.SerializeToString,
            ),
            'LastValsetRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.LastValsetRequests,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastValsetRequestsRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastValsetRequestsResponse.SerializeToString,
            ),
            'LastPendingValsetRequestByAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.LastPendingValsetRequestByAddr,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingValsetRequestByAddrRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingValsetRequestByAddrResponse.SerializeToString,
            ),
            'LastEventByAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.LastEventByAddr,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastEventByAddrRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastEventByAddrResponse.SerializeToString,
            ),
            'GetPendingSendToEth': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPendingSendToEth,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryPendingSendToEth.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryPendingSendToEthResponse.SerializeToString,
            ),
            'BatchFees': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchFees,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchFeeRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchFeeResponse.SerializeToString,
            ),
            'OutgoingTxBatches': grpc.unary_unary_rpc_method_handler(
                    servicer.OutgoingTxBatches,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesResponse.SerializeToString,
            ),
            'LastPendingBatchRequestByAddr': grpc.unary_unary_rpc_method_handler(
                    servicer.LastPendingBatchRequestByAddr,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrResponse.SerializeToString,
            ),
            'BatchRequestByNonce': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchRequestByNonce,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchRequestByNonceRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchRequestByNonceResponse.SerializeToString,
            ),
            'BatchConfirms': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchConfirms,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchConfirmsRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchConfirmsResponse.SerializeToString,
            ),
            'ERC20ToDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.ERC20ToDenom,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryERC20ToDenomRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryERC20ToDenomResponse.SerializeToString,
            ),
            'DenomToERC20': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomToERC20,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDenomToERC20Request.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDenomToERC20Response.SerializeToString,
            ),
            'GetDelegateKeyByValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegateKeyByValidator,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByValidatorAddress.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByValidatorAddressResponse.SerializeToString,
            ),
            'GetDelegateKeyByEth': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegateKeyByEth,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByEthAddress.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByEthAddressResponse.SerializeToString,
            ),
            'GetDelegateKeyByOrchestrator': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegateKeyByOrchestrator,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByOrchestratorAddress.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByOrchestratorAddressResponse.SerializeToString,
            ),
            'PeggyModuleState': grpc.unary_unary_rpc_method_handler(
                    servicer.PeggyModuleState,
                    request_deserializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryModuleStateRequest.FromString,
                    response_serializer=injective_dot_peggy_dot_v1_dot_query__pb2.QueryModuleStateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.peggy.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/Params',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CurrentValset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/CurrentValset',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryCurrentValsetRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryCurrentValsetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValsetRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/ValsetRequest',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetRequestRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValsetConfirm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/ValsetConfirm',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValsetConfirmsByNonce(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/ValsetConfirmsByNonce',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmsByNonceRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryValsetConfirmsByNonceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LastValsetRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/LastValsetRequests',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastValsetRequestsRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastValsetRequestsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LastPendingValsetRequestByAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/LastPendingValsetRequestByAddr',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingValsetRequestByAddrRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingValsetRequestByAddrResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LastEventByAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/LastEventByAddr',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastEventByAddrRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastEventByAddrResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPendingSendToEth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/GetPendingSendToEth',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryPendingSendToEth.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryPendingSendToEthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchFees(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/BatchFees',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchFeeRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchFeeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OutgoingTxBatches(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/OutgoingTxBatches',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryOutgoingTxBatchesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LastPendingBatchRequestByAddr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/LastPendingBatchRequestByAddr',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryLastPendingBatchRequestByAddrResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchRequestByNonce(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/BatchRequestByNonce',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchRequestByNonceRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchRequestByNonceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchConfirms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/BatchConfirms',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchConfirmsRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryBatchConfirmsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ERC20ToDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/ERC20ToDenom',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryERC20ToDenomRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryERC20ToDenomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenomToERC20(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/DenomToERC20',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryDenomToERC20Request.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryDenomToERC20Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDelegateKeyByValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/GetDelegateKeyByValidator',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByValidatorAddress.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByValidatorAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDelegateKeyByEth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/GetDelegateKeyByEth',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByEthAddress.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByEthAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDelegateKeyByOrchestrator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/GetDelegateKeyByOrchestrator',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByOrchestratorAddress.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryDelegateKeysByOrchestratorAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PeggyModuleState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.peggy.v1.Query/PeggyModuleState',
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
            injective_dot_peggy_dot_v1_dot_query__pb2.QueryModuleStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/v1beta1/authz.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/authz/v1beta1/authz.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"6\n\x14GenericAuthorization\x12\x0b\n\x03msg\x18\x01 \x01(\t:\x11\xd2\xb4-\rAuthorization\"\x81\x01\n\x05Grant\x12>\n\rauthorization\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x11\xca\xb4-\rAuthorization\x12\x38\n\nexpiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\"\xb0\x01\n\x12GrantAuthorization\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12>\n\rauthorization\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x11\xca\xb4-\rAuthorization\x12\x38\n\nexpiration\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x42*Z$github.com/cosmos/cosmos-sdk/x/authz\xc8\xe1\x1e\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.authz_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz\310\341\036\000'
  _GENERICAUTHORIZATION._options = None
  _GENERICAUTHORIZATION._serialized_options = b'\322\264-\rAuthorization'
  _GRANT.fields_by_name['authorization']._options = None
  _GRANT.fields_by_name['authorization']._serialized_options = b'\312\264-\rAuthorization'
  _GRANT.fields_by_name['expiration']._options = None
  _GRANT.fields_by_name['expiration']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _GRANTAUTHORIZATION.fields_by_name['authorization']._options = None
  _GRANTAUTHORIZATION.fields_by_name['authorization']._serialized_options = b'\312\264-\rAuthorization'
  _GRANTAUTHORIZATION.fields_by_name['expiration']._options = None
  _GRANTAUTHORIZATION.fields_by_name['expiration']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _GENERICAUTHORIZATION._serialized_start=167
  _GENERICAUTHORIZATION._serialized_end=221
  _GRANT._serialized_start=224
  _GRANT._serialized_end=353
  _GRANTAUTHORIZATION._serialized_start=356
  _GRANTAUTHORIZATION._serialized_end=532
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from injective.exchange.v1beta1 import tx_pb2 as injective_dot_exchange_dot_v1beta1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the exchange Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Deposit = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/Deposit',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgDeposit.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgDepositResponse.FromString,
                )
        self.Withdraw = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/Withdraw',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgWithdraw.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgWithdrawResponse.FromString,
                )
        self.InstantSpotMarketLaunch = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/InstantSpotMarketLaunch',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantSpotMarketLaunch.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantSpotMarketLaunchResponse.FromString,
                )
        self.InstantPerpetualMarketLaunch = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/InstantPerpetualMarketLaunch',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantPerpetualMarketLaunch.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantPerpetualMarketLaunchResponse.FromString,
                )
        self.InstantExpiryFuturesMarketLaunch = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/InstantExpiryFuturesMarketLaunch',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantExpiryFuturesMarketLaunch.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantExpiryFuturesMarketLaunchResponse.FromString,
                )
        self.CreateSpotLimitOrder = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/CreateSpotLimitOrder',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotLimitOrder.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotLimitOrderResponse.FromString,
                )
        self.BatchCreateSpotLimitOrders = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/BatchCreateSpotLimitOrders',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateSpotLimitOrders.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateSpotLimitOrdersResponse.FromString,
                )
        self.CreateSpotMarketOrder = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/CreateSpotMarketOrder',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotMarketOrder.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotMarketOrderResponse.FromString,
                )
        self.CancelSpotOrder = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/CancelSpotOrder',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelSpotOrder.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelSpotOrderResponse.FromString,
                )
        self.BatchCancelSpotOrders = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/BatchCancelSpotOrders',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelSpotOrders.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelSpotOrdersResponse.FromString,
                )
        self.BatchUpdateOrders = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/BatchUpdateOrders',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchUpdateOrders.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchUpdateOrdersResponse.FromString,
                )
        self.PrivilegedExecuteContract = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/PrivilegedExecuteContract',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgPrivilegedExecuteContract.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgPrivilegedExecuteContractResponse.FromString,
                )
        self.CreateDerivativeLimitOrder = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/CreateDerivativeLimitOrder',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeLimitOrder.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeLimitOrderResponse.FromString,
                )
        self.BatchCreateDerivativeLimitOrders = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/BatchCreateDerivativeLimitOrders',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateDerivativeLimitOrders.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateDerivativeLimitOrdersResponse.FromString,
                )
        self.CreateDerivativeMarketOrder = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/CreateDerivativeMarketOrder',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeMarketOrder.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeMarketOrderResponse.FromString,
                )
        self.CancelDerivativeOrder = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/CancelDerivativeOrder',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelDerivativeOrder.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelDerivativeOrderResponse.FromString,
                )
        self.BatchCancelDerivativeOrders = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/BatchCancelDerivativeOrders',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelDerivativeOrders.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelDerivativeOrdersResponse.FromString,
                )
        self.InstantBinaryOptionsMarketLaunch = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/InstantBinaryOptionsMarketLaunch',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantBinaryOptionsMarketLaunch.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantBinaryOptionsMarketLaunchResponse.FromString,
                )
        self.CreateBinaryOptionsLimitOrder = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/CreateBinaryOptionsLimitOrder',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsLimitOrder.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsLimitOrderResponse.FromString,
                )
        self.CreateBinaryOptionsMarketOrder = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/CreateBinaryOptionsMarketOrder',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsMarketOrder.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsMarketOrderResponse.FromString,
                )
        self.CancelBinaryOptionsOrder = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/CancelBinaryOptionsOrder',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelBinaryOptionsOrder.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelBinaryOptionsOrderResponse.FromString,
                )
        self.BatchCancelBinaryOptionsOrders = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/BatchCancelBinaryOptionsOrders',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelBinaryOptionsOrders.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelBinaryOptionsOrdersResponse.FromString,
                )
        self.SubaccountTransfer = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/SubaccountTransfer',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgSubaccountTransfer.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgSubaccountTransferResponse.FromString,
                )
        self.ExternalTransfer = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/ExternalTransfer',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgExternalTransfer.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgExternalTransferResponse.FromString,
                )
        self.LiquidatePosition = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/LiquidatePosition',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgLiquidatePosition.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgLiquidatePositionResponse.FromString,
                )
        self.IncreasePositionMargin = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/IncreasePositionMargin',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgIncreasePositionMargin.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgIncreasePositionMarginResponse.FromString,
                )
        self.RewardsOptOut = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/RewardsOptOut',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgRewardsOptOut.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgRewardsOptOutResponse.FromString,
                )
        self.AdminUpdateBinaryOptionsMarket = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/AdminUpdateBinaryOptionsMarket',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgAdminUpdateBinaryOptionsMarket.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgAdminUpdateBinaryOptionsMarketResponse.FromString,
                )
        self.ReclaimLockedFunds = channel.unary_unary(
                '/injective.exchange.v1beta1.Msg/ReclaimLockedFunds',
                request_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgReclaimLockedFunds.SerializeToString,
                response_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgReclaimLockedFundsResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the exchange Msg service.
    """

    def Deposit(self, request, context):
        """Deposit defines a method for transferring coins from the sender's bank balance into the subaccount's exchange deposits
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Withdraw(self, request, context):
        """Withdraw defines a method for withdrawing coins from a subaccount's deposits to the user's bank balance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstantSpotMarketLaunch(self, request, context):
        """InstantSpotMarketLaunch defines method for creating a spot market by paying listing fee without governance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstantPerpetualMarketLaunch(self, request, context):
        """InstantPerpetualMarketLaunch defines a method for creating a new perpetual futures market by paying listing fee without governance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstantExpiryFuturesMarketLaunch(self, request, context):
        """InstantExpiryFuturesMarketLaunch defines a method for creating a new expiry futures market by paying listing fee without governance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSpotLimitOrder(self, request, context):
        """CreateSpotLimitOrder defines a method for creating a new spot limit order.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchCreateSpotLimitOrders(self, request, context):
        """BatchCreateSpotLimitOrder defines a method for creating a new batch of spot limit orders.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSpotMarketOrder(self, request, context):
        """CreateSpotMarketOrder defines a method for creating a new spot market order.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelSpotOrder(self, request, context):
        """MsgCancelSpotOrder defines a method for cancelling a spot order.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchCancelSpotOrders(self, request, context):
        """BatchCancelSpotOrders defines a method for cancelling a batch of spot orders in a given market.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchUpdateOrders(self, request, context):
        """BatchUpdateOrders defines a method for updating a batch of orders.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PrivilegedExecuteContract(self, request, context):
        """PrivilegedExecuteContract defines a method for executing a Cosmwasm contract from the exchange module with privileged capabilities.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDerivativeLimitOrder(self, request, context):
        """CreateDerivativeLimitOrder defines a method for creating a new derivative limit order.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchCreateDerivativeLimitOrders(self, request, context):
        """BatchCreateDerivativeLimitOrders defines a method for creating a new batch of derivative limit orders.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDerivativeMarketOrder(self, request, context):
        """MsgCreateDerivativeLimitOrder defines a method for creating a new derivative market order.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelDerivativeOrder(self, request, context):
        """MsgCancelDerivativeOrder defines a method for cancelling a derivative order.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchCancelDerivativeOrders(self, request, context):
        """MsgBatchCancelDerivativeOrders defines a method for cancelling a batch of derivative limit orders.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstantBinaryOptionsMarketLaunch(self, request, context):
        """InstantBinaryOptionsMarketLaunch defines method for creating a binary options market by paying listing fee without governance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBinaryOptionsLimitOrder(self, request, context):
        """CreateBinaryOptionsLimitOrder defines a method for creating a new binary options limit order.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBinaryOptionsMarketOrder(self, request, context):
        """CreateBinaryOptionsMarketOrder defines a method for creating a new binary options market order.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelBinaryOptionsOrder(self, request, context):
        """MsgCancelBinaryOptionsOrder defines a method for cancelling a binary options order.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchCancelBinaryOptionsOrders(self, request, context):
        """BatchCancelBinaryOptionsOrders defines a method for cancelling a batch of binary options limit orders.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubaccountTransfer(self, request, context):
        """SubaccountTransfer defines a method for transfer between subaccounts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExternalTransfer(self, request, context):
        """ExternalTransfer defines a method for transfer between external accounts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LiquidatePosition(self, request, context):
        """LiquidatePosition defines a method for liquidating a position
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IncreasePositionMargin(self, request, context):
        """IncreasePositionMargin defines a method for increasing margin of a position
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RewardsOptOut(self, request, context):
        """RewardsOptOut defines a method for opting out of rewards
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminUpdateBinaryOptionsMarket(self, request, context):
        """AdminUpdateBinaryOptionsMarket defines method for updating a binary options market by admin
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReclaimLockedFunds(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Deposit': grpc.unary_unary_rpc_method_handler(
                    servicer.Deposit,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgDeposit.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgDepositResponse.SerializeToString,
            ),
            'Withdraw': grpc.unary_unary_rpc_method_handler(
                    servicer.Withdraw,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgWithdraw.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgWithdrawResponse.SerializeToString,
            ),
            'InstantSpotMarketLaunch': grpc.unary_unary_rpc_method_handler(
                    servicer.InstantSpotMarketLaunch,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantSpotMarketLaunch.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantSpotMarketLaunchResponse.SerializeToString,
            ),
            'InstantPerpetualMarketLaunch': grpc.unary_unary_rpc_method_handler(
                    servicer.InstantPerpetualMarketLaunch,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantPerpetualMarketLaunch.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantPerpetualMarketLaunchResponse.SerializeToString,
            ),
            'InstantExpiryFuturesMarketLaunch': grpc.unary_unary_rpc_method_handler(
                    servicer.InstantExpiryFuturesMarketLaunch,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantExpiryFuturesMarketLaunch.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantExpiryFuturesMarketLaunchResponse.SerializeToString,
            ),
            'CreateSpotLimitOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSpotLimitOrder,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotLimitOrder.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotLimitOrderResponse.SerializeToString,
            ),
            'BatchCreateSpotLimitOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchCreateSpotLimitOrders,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateSpotLimitOrders.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateSpotLimitOrdersResponse.SerializeToString,
            ),
            'CreateSpotMarketOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSpotMarketOrder,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotMarketOrder.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotMarketOrderResponse.SerializeToString,
            ),
            'CancelSpotOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelSpotOrder,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelSpotOrder.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelSpotOrderResponse.SerializeToString,
            ),
            'BatchCancelSpotOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchCancelSpotOrders,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelSpotOrders.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelSpotOrdersResponse.SerializeToString,
            ),
            'BatchUpdateOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchUpdateOrders,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchUpdateOrders.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchUpdateOrdersResponse.SerializeToString,
            ),
            'PrivilegedExecuteContract': grpc.unary_unary_rpc_method_handler(
                    servicer.PrivilegedExecuteContract,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgPrivilegedExecuteContract.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgPrivilegedExecuteContractResponse.SerializeToString,
            ),
            'CreateDerivativeLimitOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDerivativeLimitOrder,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeLimitOrder.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeLimitOrderResponse.SerializeToString,
            ),
            'BatchCreateDerivativeLimitOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchCreateDerivativeLimitOrders,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateDerivativeLimitOrders.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateDerivativeLimitOrdersResponse.SerializeToString,
            ),
            'CreateDerivativeMarketOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDerivativeMarketOrder,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeMarketOrder.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeMarketOrderResponse.SerializeToString,
            ),
            'CancelDerivativeOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelDerivativeOrder,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelDerivativeOrder.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelDerivativeOrderResponse.SerializeToString,
            ),
            'BatchCancelDerivativeOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchCancelDerivativeOrders,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelDerivativeOrders.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelDerivativeOrdersResponse.SerializeToString,
            ),
            'InstantBinaryOptionsMarketLaunch': grpc.unary_unary_rpc_method_handler(
                    servicer.InstantBinaryOptionsMarketLaunch,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantBinaryOptionsMarketLaunch.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantBinaryOptionsMarketLaunchResponse.SerializeToString,
            ),
            'CreateBinaryOptionsLimitOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBinaryOptionsLimitOrder,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsLimitOrder.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsLimitOrderResponse.SerializeToString,
            ),
            'CreateBinaryOptionsMarketOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBinaryOptionsMarketOrder,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsMarketOrder.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsMarketOrderResponse.SerializeToString,
            ),
            'CancelBinaryOptionsOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelBinaryOptionsOrder,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelBinaryOptionsOrder.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelBinaryOptionsOrderResponse.SerializeToString,
            ),
            'BatchCancelBinaryOptionsOrders': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchCancelBinaryOptionsOrders,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelBinaryOptionsOrders.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelBinaryOptionsOrdersResponse.SerializeToString,
            ),
            'SubaccountTransfer': grpc.unary_unary_rpc_method_handler(
                    servicer.SubaccountTransfer,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgSubaccountTransfer.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgSubaccountTransferResponse.SerializeToString,
            ),
            'ExternalTransfer': grpc.unary_unary_rpc_method_handler(
                    servicer.ExternalTransfer,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgExternalTransfer.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgExternalTransferResponse.SerializeToString,
            ),
            'LiquidatePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.LiquidatePosition,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgLiquidatePosition.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgLiquidatePositionResponse.SerializeToString,
            ),
            'IncreasePositionMargin': grpc.unary_unary_rpc_method_handler(
                    servicer.IncreasePositionMargin,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgIncreasePositionMargin.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgIncreasePositionMarginResponse.SerializeToString,
            ),
            'RewardsOptOut': grpc.unary_unary_rpc_method_handler(
                    servicer.RewardsOptOut,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgRewardsOptOut.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgRewardsOptOutResponse.SerializeToString,
            ),
            'AdminUpdateBinaryOptionsMarket': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminUpdateBinaryOptionsMarket,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgAdminUpdateBinaryOptionsMarket.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgAdminUpdateBinaryOptionsMarketResponse.SerializeToString,
            ),
            'ReclaimLockedFunds': grpc.unary_unary_rpc_method_handler(
                    servicer.ReclaimLockedFunds,
                    request_deserializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgReclaimLockedFunds.FromString,
                    response_serializer=injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgReclaimLockedFundsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.exchange.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the exchange Msg service.
    """

    @staticmethod
    def Deposit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/Deposit',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgDeposit.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgDepositResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Withdraw(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/Withdraw',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgWithdraw.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgWithdrawResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstantSpotMarketLaunch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/InstantSpotMarketLaunch',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantSpotMarketLaunch.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantSpotMarketLaunchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstantPerpetualMarketLaunch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/InstantPerpetualMarketLaunch',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantPerpetualMarketLaunch.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantPerpetualMarketLaunchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstantExpiryFuturesMarketLaunch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/InstantExpiryFuturesMarketLaunch',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantExpiryFuturesMarketLaunch.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantExpiryFuturesMarketLaunchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSpotLimitOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/CreateSpotLimitOrder',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotLimitOrder.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotLimitOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchCreateSpotLimitOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/BatchCreateSpotLimitOrders',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateSpotLimitOrders.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateSpotLimitOrdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSpotMarketOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/CreateSpotMarketOrder',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotMarketOrder.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateSpotMarketOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelSpotOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/CancelSpotOrder',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelSpotOrder.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelSpotOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchCancelSpotOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/BatchCancelSpotOrders',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelSpotOrders.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelSpotOrdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchUpdateOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/BatchUpdateOrders',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchUpdateOrders.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchUpdateOrdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PrivilegedExecuteContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/PrivilegedExecuteContract',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgPrivilegedExecuteContract.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgPrivilegedExecuteContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDerivativeLimitOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/CreateDerivativeLimitOrder',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeLimitOrder.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeLimitOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchCreateDerivativeLimitOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/BatchCreateDerivativeLimitOrders',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateDerivativeLimitOrders.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCreateDerivativeLimitOrdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDerivativeMarketOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/CreateDerivativeMarketOrder',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeMarketOrder.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateDerivativeMarketOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelDerivativeOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/CancelDerivativeOrder',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelDerivativeOrder.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelDerivativeOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchCancelDerivativeOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/BatchCancelDerivativeOrders',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelDerivativeOrders.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelDerivativeOrdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstantBinaryOptionsMarketLaunch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/InstantBinaryOptionsMarketLaunch',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantBinaryOptionsMarketLaunch.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgInstantBinaryOptionsMarketLaunchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateBinaryOptionsLimitOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/CreateBinaryOptionsLimitOrder',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsLimitOrder.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsLimitOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateBinaryOptionsMarketOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/CreateBinaryOptionsMarketOrder',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsMarketOrder.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCreateBinaryOptionsMarketOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelBinaryOptionsOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/CancelBinaryOptionsOrder',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelBinaryOptionsOrder.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgCancelBinaryOptionsOrderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchCancelBinaryOptionsOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/BatchCancelBinaryOptionsOrders',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelBinaryOptionsOrders.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgBatchCancelBinaryOptionsOrdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubaccountTransfer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/SubaccountTransfer',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgSubaccountTransfer.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgSubaccountTransferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExternalTransfer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/ExternalTransfer',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgExternalTransfer.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgExternalTransferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LiquidatePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/LiquidatePosition',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgLiquidatePosition.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgLiquidatePositionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IncreasePositionMargin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/IncreasePositionMargin',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgIncreasePositionMargin.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgIncreasePositionMarginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RewardsOptOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/RewardsOptOut',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgRewardsOptOut.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgRewardsOptOutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminUpdateBinaryOptionsMarket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/AdminUpdateBinaryOptionsMarket',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgAdminUpdateBinaryOptionsMarket.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgAdminUpdateBinaryOptionsMarketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReclaimLockedFunds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.exchange.v1beta1.Msg/ReclaimLockedFunds',
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgReclaimLockedFunds.SerializeToString,
            injective_dot_exchange_dot_v1beta1_dot_tx__pb2.MsgReclaimLockedFundsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_meta_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!exchange/injective_meta_rpc.proto\x12\x12injective_meta_rpc\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\x10\n\x0eVersionRequest\"\x8f\x01\n\x0fVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12=\n\x05\x62uild\x18\x02 \x03(\x0b\x32..injective_meta_rpc.VersionResponse.BuildEntry\x1a,\n\nBuildEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\" \n\x0bInfoRequest\x12\x11\n\ttimestamp\x18\x01 \x01(\x12\"\xc1\x01\n\x0cInfoResponse\x12\x11\n\ttimestamp\x18\x01 \x01(\x12\x12\x13\n\x0bserver_time\x18\x02 \x01(\x12\x12\x0f\n\x07version\x18\x03 \x01(\t\x12:\n\x05\x62uild\x18\x04 \x03(\x0b\x32+.injective_meta_rpc.InfoResponse.BuildEntry\x12\x0e\n\x06region\x18\x05 \x01(\t\x1a,\n\nBuildEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x18\n\x16StreamKeepaliveRequest\"Q\n\x17StreamKeepaliveResponse\x12\r\n\x05\x65vent\x18\x01 \x01(\t\x12\x14\n\x0cnew_endpoint\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"&\n\x14TokenMetadataRequest\x12\x0e\n\x06\x64\x65noms\x18\x01 \x03(\t\"Q\n\x15TokenMetadataResponse\x12\x38\n\x06tokens\x18\x01 \x03(\x0b\x32(.injective_meta_rpc.TokenMetadataElement\"\x93\x01\n\x14TokenMetadataElement\x12\x18\n\x10\x65thereum_address\x18\x01 \x01(\t\x12\x14\n\x0c\x63oingecko_id\x18\x02 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06symbol\x18\x05 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x06 \x01(\x11\x12\x0c\n\x04logo\x18\x07 \x01(\t2\xd0\x03\n\x10InjectiveMetaRPC\x12I\n\x04Ping\x12\x1f.injective_meta_rpc.PingRequest\x1a .injective_meta_rpc.PingResponse\x12R\n\x07Version\x12\".injective_meta_rpc.VersionRequest\x1a#.injective_meta_rpc.VersionResponse\x12I\n\x04Info\x12\x1f.injective_meta_rpc.InfoRequest\x1a .injective_meta_rpc.InfoResponse\x12l\n\x0fStreamKeepalive\x12*.injective_meta_rpc.StreamKeepaliveRequest\x1a+.injective_meta_rpc.StreamKeepaliveResponse0\x01\x12\x64\n\rTokenMetadata\x12(.injective_meta_rpc.TokenMetadataRequest\x1a).injective_meta_rpc.TokenMetadataResponseB\x17Z\x15/injective_meta_rpcpbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_meta_rpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\025/injective_meta_rpcpb'
  _VERSIONRESPONSE_BUILDENTRY._options = None
  _VERSIONRESPONSE_BUILDENTRY._serialized_options = b'8\001'
  _INFORESPONSE_BUILDENTRY._options = None
  _INFORESPONSE_BUILDENTRY._serialized_options = b'8\001'
  _PINGREQUEST._serialized_start=57
  _PINGREQUEST._serialized_end=70
  _PINGRESPONSE._serialized_start=72
  _PINGRESPONSE._serialized_end=86
  _VERSIONREQUEST._serialized_start=88
  _VERSIONREQUEST._serialized_end=104
  _VERSIONRESPONSE._serialized_start=107
  _VERSIONRESPONSE._serialized_end=250
  _VERSIONRESPONSE_BUILDENTRY._serialized_start=206
  _VERSIONRESPONSE_BUILDENTRY._serialized_end=250
  _INFOREQUEST._serialized_start=252
  _INFOREQUEST._serialized_end=284
  _INFORESPONSE._serialized_start=287
  _INFORESPONSE._serialized_end=480
  _INFORESPONSE_BUILDENTRY._serialized_start=206
  _INFORESPONSE_BUILDENTRY._serialized_end=250
  _STREAMKEEPALIVEREQUEST._serialized_start=482
  _STREAMKEEPALIVEREQUEST._serialized_end=506
  _STREAMKEEPALIVERESPONSE._serialized_start=508
  _STREAMKEEPALIVERESPONSE._serialized_end=589
  _TOKENMETADATAREQUEST._serialized_start=591
  _TOKENMETADATAREQUEST._serialized_end=629
  _TOKENMETADATARESPONSE._serialized_start=631
  _TOKENMETADATARESPONSE._serialized_end=712
  _TOKENMETADATAELEMENT._serialized_start=715
  _TOKENMETADATAELEMENT._serialized_end=862
  _INJECTIVEMETARPC._serialized_start=865
  _INJECTIVEMETARPC._serialized_end=1329
# @@protoc_insertion_point(module_scope)
